@@ -288,16 +288,16 @@ static BOOL debugLeaks;
 
   e = [urlStrings objectEnumerator];
   while (ok && (tmp = [e nextObject]))
+  {
+    value = [defaults stringForKey: tmp];
+    if (value)
+      [self _checkTableWithCM: cm tableURL: value andType: tmp];
+    else
     {
-      value = [defaults stringForKey: tmp];
-      if (value)
-	  [self _checkTableWithCM: cm tableURL: value andType: tmp];
-      else
-	{
-	  [self errorWithFormat: @"No value specified for '%@'", tmp];
-	  ok = NO;
-	}
+      [self errorWithFormat: @"No value specified for '%@'", tmp];
+      ok = NO;
     }
+  }
 
   if (combined)
     {
@@ -322,9 +322,15 @@ static BOOL debugLeaks;
       
       // Create the email alarms table, if required
       if ([defaults enableEMailAlarms])
-	{
-	  [[fm alarmsFolder] createFolderIfNotExists];
-	}
+      {
+        [[fm alarmsFolder] createFolderIfNotExists];
+      }
+
+      //Create mandatory openId table, if used
+      if([defaults hasOpenIdType])
+      {
+        [[fm openIdFolder] createFolderIfNotExists];
+      }
     }
 
   return ok;
@@ -374,8 +380,10 @@ static BOOL debugLeaks;
 
   request = [_ctx request];
   login = [SOGoUser getDecryptedUsernameIfNeeded: _key request: request];
-
-  user = [SOGoUser userWithLogin: login roles: nil];
+  if([login isEqualToString: @"changeLanguage"])
+    user = nil;
+  else
+    user = [SOGoUser userWithLogin: login roles: nil];
   if (user)
     userFolder = [$(@"SOGoUserFolder") objectWithName: login
                                           inContainer: self];
