@@ -1429,11 +1429,22 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   NSMutableArray *contacts;
   EOQualifier *qualifier;
   unsigned int i;
+  NSMutableString *s;
   NSString *sortAttribute;
   BOOL sortReverse;
 
   contacts = [NSMutableArray array];
 
+  if(theDomain != nil && [theDomain length] > 0)
+  {
+    if ([_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
+    {
+      s = [NSMutableString stringWithString: _pristineBaseDN];
+      [s replaceOccurrencesOfString: @"%d"  withString: theDomain  options: 0  range: NSMakeRange(0, [s length])];
+      ASSIGN(_baseDN, s);
+    }
+  }
+
   if ([match length] > 0 || !_listRequiresDot)
     {
       ldapConnection = [self _ldapConnection];
@@ -2290,8 +2301,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
   NSRange r;
 
   r = [theLogin rangeOfString: @"@"];
-  if (r.location != NSNotFound &&
-      [_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
+  if (r.location != NSNotFound && [_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
     {
       s = [NSMutableString stringWithString: _pristineBaseDN];
       [s replaceOccurrencesOfString: @"%d"  withString: [theLogin substringFromIndex: r.location+1]  options: 0  range: NSMakeRange(0, [s length])];
@@ -2306,7 +2316,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
 
 - (NSArray *) membersForGroupWithUID: (NSString *) uid
 {
-  NSMutableArray *dns, *uids;
+  NSMutableArray *dns, *uids, *userLogins;
   NSString *dn, *login;
   SOGoUserManager *um;
   NSDictionary *d, *contactInfos;
@@ -2327,6 +2337,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
       members = [NSMutableArray new];
       uids = [NSMutableArray array];
       dns = [NSMutableArray array];
+      userLogins = [NSMutableArray array];
 
       // We check if it's a static group
       // Fetch "members" - we get DNs
@@ -2358,6 +2369,13 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
               pool = [NSAutoreleasePool new];
               dn = [dns objectAtIndex: i];
               login = [um getLoginForDN: [dn lowercaseString]];
+              if([userLogins containsObject: login])
+              {
+                [pool release];
+                continue; //user alrady fetch
+              }
+              if(login != nil)
+                [userLogins addObject: login];
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
@@ -2385,6 +2403,13 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
             {
               pool = [NSAutoreleasePool new];
               login = [uids objectAtIndex: i];
+              if([userLogins containsObject: login])
+              {
+                [pool release];
+                continue; //user alrady fetch
+              }
+              if(login != nil)
+                [userLogins addObject: login];
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
@@ -2456,4 +2481,4 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
   return rc;
 }
 
-@end
+@end
\ No newline at end of file
