@@ -60,6 +60,7 @@
 - (NSString *) vacationDefaultSubject;
 - (NSString *) vacationHeaderTemplateFile;
 - (NSString *) vacationFooterTemplateFile;
+- (BOOL) vacationAllowZeroDays;
 - (NSString *) mailingMechanism;
 - (NSString *) smtpServer;
 - (BOOL)smtpMasterUserEnabled;
@@ -77,6 +78,7 @@
 - (BOOL) appointmentSendEMailNotifications;
 - (BOOL) foldersSendEMailNotifications;
 - (NSArray *) calendarDefaultRoles;
+- (NSString *) calendarJistiBaseUrl;
 - (NSArray *) contactsDefaultRoles;
 - (NSArray *) refreshViewIntervals;
 - (NSString *) subscriptionFolderFormat;
