@@ -169,6 +169,16 @@
   return [self stringArrayForKey: @"SOGoCalendarDefaultRoles"];
 }
 
+- (NSString *) calendarJistiBaseUrl
+{
+  NSString *jitsiBaseUrl;
+  jitsiBaseUrl = [self stringForKey: @"SOGoCalendarJitsiBaseUrl"];
+  if(!jitsiBaseUrl)
+    jitsiBaseUrl = @"https://meet.jit.si";
+
+  return jitsiBaseUrl;
+}
+
 - (NSArray *) contactsDefaultRoles
 {
   return [self stringArrayForKey: @"SOGoContactsDefaultRoles"];
@@ -267,6 +277,18 @@
   return [self stringForKey: @"SOGoVacationFooterTemplateFile"];
 }
 
+- (BOOL) vacationAllowZeroDays
+{
+  id o;
+
+  o = [self stringForKey: @"SOGoVacationAllowZeroDays"];
+
+  if (o)
+    return [o boolValue];
+
+  return NO;
+}
+
 - (NSString *) mailingMechanism
 {
   NSString *mailingMechanism;
