@@ -14,6 +14,7 @@
       this.calendarService = Calendar;
       this.service = Component;
       this.component = stateComponent;
+      this.isDeleting = false;
 
       // Put organizer in an array to display it as an mdChip
       this.organizer = [stateComponent.organizer];
@@ -23,6 +24,10 @@
       $mdDialog.hide();
     };
 
+    this.changed = function (d) {
+      console.log(d);
+    };
+
     this.highPriority = function () {
       return (this.component &&
               this.component.priority &&
@@ -140,17 +145,26 @@
     };
 
     this.deleteOccurrence = function () {
-      this.component.remove(true).then(function() {
-        $rootScope.$emit('calendars:list');
-        $mdDialog.hide();
-      });
+      if (!this.isDeleting) {
+        this.isDeleting = true;
+        this.component.remove(true).then(function() {
+          $rootScope.$emit('calendars:list');
+          $mdDialog.hide();
+          vm.isDeleting = false;
+        });
+      }
     };
 
     this.deleteAllOccurrences = function () {
-      this.component.remove().then(function() {
-        $rootScope.$emit('calendars:list');
-        $mdDialog.hide();
-      });
+      if (!this.isDeleting) {
+        this.isDeleting = true;
+        this.component.remove().then(function () {
+          $rootScope.$emit('calendars:list');
+          $mdDialog.hide();
+          vm.isDeleting = false;
+        });
+      }
+      
     };
 
     this.toggleRawSource = function ($event) {
@@ -216,6 +230,9 @@
       this.categories = {};
       this.showRecurrenceEditor = this.component.$hasCustomRepeat;
       this.showAttendeesEditor = this.component.attendees && this.component.attendees.length;
+      this.isFullscreen = (typeof screen.orientation !== 'undefined' && screen.orientation && 'portrait-primary' == screen.orientation.type);
+      this.originalModalCancel = $mdDialog.cancel;
+      this.preferences = Preferences;
 
       if (this.component.type == 'appointment') {
         this.component.initAttendees();
@@ -245,13 +262,67 @@
 
       dayStartTime = parseInt(Preferences.defaults.SOGoDayStartTime);
       dayEndTime = parseInt(Preferences.defaults.SOGoDayEndTime);
+
+      this.originalHash = this.hash(this.component);
+      $mdDialog.cancel = function () {
+        if (vm.originalHash === vm.hash(vm.component)  || confirm(l('You have modified data unsaved. Do you want to close popup and loose data ?'))) {
+          $mdDialog.cancel = vm.originalModalCancel;
+          return vm.originalModalCancel();
+        }
+      };
     };
 
+    this.hash = function (data) {
+      var hash = 0, i, chr, edata, json;
+      edata = {
+        repeat: data.repeat,
+        pid: data.pid,
+        destinationCalendar: data.destinationCalendar,
+        classification: data.classification,
+        categories: data.categories,
+        alarm: data.alarm,
+        summary: data.summary,
+        status: data.status,
+        organizer: data.organizer,
+        location: data.location,
+        isAllDay: data.isAllDay,
+        comment: data.comment,
+        attendees: data.attendees
+      };
+      if (edata.organizer && edata.organizer.freebusy) {
+        edata.organizer.freebusy = {};
+      }
+      if (edata.attendees) {
+        for (i = 0; i < edata.attendees.length; i++) {
+          edata.attendees[i].freebusy = {};
+        }
+      }
+      json = JSON.stringify(edata);
+
+      if (json.length === 0) return hash;
+      for (i = 0; i < json.length; i++) {
+        chr = json.charCodeAt(i);
+        hash = ((hash << 5) - hash) + chr;
+        hash |= 0;
+      }
+
+      return hash;
+    }
+
     this.addAttachUrl = function () {
       var i = this.component.addAttachUrl('');
       focus('attachUrl_' + i);
     };
 
+    this.addJitsiUrl = function () {
+      var jitsiBaseUrl = "https://meet.jit.si";
+      if(this.preferences.defaults && this.preferences.defaults.SOGoCalendarJitsiBaseUrl)
+        jitsiBaseUrl = this.preferences.defaults.SOGoCalendarJitsiBaseUrl;
+      var jitsiUrl = jitsiBaseUrl + "/SOGo_meeting/" + crypto.randomUUID();
+      var i = this.component.addAttachUrl(jitsiUrl);
+      focus('attachUrl_' + i);
+    };
+
     this.toggleRecurrenceEditor = function () {
       this.showRecurrenceEditor = !this.showRecurrenceEditor;
       this.component.$hasCustomRepeat = this.showRecurrenceEditor;
@@ -267,22 +338,16 @@
         this.component.repeat.month.type == 'bymonthday';
     };
 
-    this.frequencies = function () {
-      return _.filter($window.repeatFrequencies, function (frequency) {
-        return frequency[0] != 'custom' || vm.component.repeat.frequency == 'custom';
-      });
-    };
-
     this.changeFrequency = function () {
       if (this.component.repeat.frequency == 'custom')
         this.showRecurrenceEditor = true;
     };
 
     this.destinationCalendars = function () {
-      if (this.component.isNew)
+      if (this.component && this.component.isNew)
         // New component, return all writable calendars
         return Calendar.$findAll(null, true);
-      else if (this.component.isErasable)
+      else if (this.component && this.component.isErasable)
         // Movable component, return all writable calendars including current one
         return Calendar.$findAll(null, true, this.component.pid);
       else
@@ -296,6 +361,10 @@
         this.component.$attendees.initOrganizer(Calendar.$get(this.component.destinationCalendar));
     };
 
+    this.toggleFullscreen = function() {
+      vm.isFullscreen = !vm.isFullscreen;
+    }
+
     // Autocomplete cards for attendees
     this.cardFilter = function ($query) {
       return AddressBook.$filterAll($query);
@@ -484,17 +553,22 @@
       this.adjustEndTime();
       this.changeAlarmRelation(form);
       this.addAttendee(this.searchText).then(function () {
+        vm.adjustStartTime();
         if (form.$valid) {
           vm.component.$save(options)
             .then(function(data) {
               $rootScope.$emit('calendars:list');
               Preferences.getAlarms();
+              $mdDialog.cancel = vm.originalModalCancel;
               $mdDialog.hide();
             }, function(response) {
-              if (response.status == CalendarSettings.ConflictHTTPErrorCode)
+              vm.allowResubmit(form);
+
+              if (response.status == CalendarSettings.ConflictHTTPErrorCode) {
                 vm.attendeeConflictError = _.isObject(response.data.message) ? response.data.message : { reject: response.data.message };
-              else
+              } else {
                 vm.edit(form);
+              }
             });
         }
       });
@@ -506,6 +580,14 @@
     };
 
     this.cancel = function (form) {
+      if (vm.originalHash === vm.hash(vm.component) || confirm(l('You have modified data unsaved. Do you want to close popup and loose data ?'))) {
+        $mdDialog.cancel = vm.originalModalCancel;
+      } else {
+        return;
+      }
+
+      $mdDialog.hide();
+      
       this.reset(form);
       if (this.component.isNew) {
         // Cancelling the creation of a component
@@ -520,6 +602,11 @@
       form.$setDirty();
     };
 
+    this.allowResubmit = function (form) {
+      form.$setPristine();
+      form.$setDirty();
+    };
+
     function getHours() {
       var hours = [];
       for (var i = 0; i <= 23; i++) {
